===============================================
LiMonaDA: Lightweight Monitor and Data Analyzer
===============================================

This project is a simple and Lightweight system and performance monitor.
I wrote it for fun, and because I needed a tool to collect, analyze and
report some health and performance indicators of the HPC cluster I
administer.

This project is **Work In Progress!**

